summaryrefslogtreecommitdiff
path: root/drivers/gpu/arm/midgard/mali_kbase_vinstr.h
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/gpu/arm/midgard/mali_kbase_vinstr.h')
-rw-r--r--drivers/gpu/arm/midgard/mali_kbase_vinstr.h37
1 files changed, 8 insertions, 29 deletions
diff --git a/drivers/gpu/arm/midgard/mali_kbase_vinstr.h b/drivers/gpu/arm/midgard/mali_kbase_vinstr.h
index 6207d25aef06..d32462aec653 100644
--- a/drivers/gpu/arm/midgard/mali_kbase_vinstr.h
+++ b/drivers/gpu/arm/midgard/mali_kbase_vinstr.h
@@ -1,6 +1,6 @@
/*
*
- * (C) COPYRIGHT 2015-2016 ARM Limited. All rights reserved.
+ * (C) COPYRIGHT 2015 ARM Limited. All rights reserved.
*
* This program is free software and is provided to you under the terms of the
* GNU General Public License version 2 as published by the Free Software
@@ -103,39 +103,18 @@ int kbase_vinstr_hwc_dump(
int kbase_vinstr_hwc_clear(struct kbase_vinstr_client *cli);
/**
- * kbase_vinstr_try_suspend - try suspending operation of a given vinstr context
+ * kbase_vinstr_hwc_suspend - suspends hardware counter collection for
+ * a given kbase context
* @vinstr_ctx: vinstr context
- *
- * Return: 0 on success, or negative if state change is in progress
- *
- * Warning: This API call is non-generic. It is meant to be used only by
- * job scheduler state machine.
- *
- * Function initiates vinstr switch to suspended state. Once it was called
- * vinstr enters suspending state. If function return non-zero value, it
- * indicates that state switch is not complete and function must be called
- * again. On state switch vinstr will trigger job scheduler state machine
- * cycle.
- */
-int kbase_vinstr_try_suspend(struct kbase_vinstr_context *vinstr_ctx);
-
-/**
- * kbase_vinstr_suspend - suspends operation of a given vinstr context
- * @vinstr_ctx: vinstr context
- *
- * Function initiates vinstr switch to suspended state. Then it blocks until
- * operation is completed.
*/
-void kbase_vinstr_suspend(struct kbase_vinstr_context *vinstr_ctx);
+void kbase_vinstr_hwc_suspend(struct kbase_vinstr_context *vinstr_ctx);
/**
* kbase_vinstr_resume - resumes operation of a given vinstr context
* @vinstr_ctx: vinstr context
- *
- * Function can be called only if it was preceded by a successful call
- * to kbase_vinstr_suspend.
*/
-void kbase_vinstr_resume(struct kbase_vinstr_context *vinstr_ctx);
+void kbase_vinstr_hwc_resume(struct kbase_vinstr_context *vinstr_ctx);
/**
* kbase_vinstr_dump_size - Return required size of dump buffer
@@ -147,7 +126,7 @@ size_t kbase_vinstr_dump_size(struct kbase_device *kbdev);
/**
* kbase_vinstr_detach_client - Detach a client from the vinstr core
- * @cli: pointer to vinstr client
+ * @cli: Pointer to vinstr client
*/
void kbase_vinstr_detach_client(struct kbase_vinstr_client *cli);
@@ -103,39 +103,18 @@ int kbase_vinstr_hwc_dump(
/**
- * kbase_vinstr_resume - resumes operation of a given vinstr context
+ * kbase_vinstr_hwc_resume - resumes hardware counter collection for
+ * a given kbase context
* @vinstr_ctx: vinstr context